(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/BehaviorSubject'), require('@angular/animations'), require('@angular/platform-browser'), require('moment'), require('@angular/forms'), require('@angular/common'), require('@angular/platform-browser/animations')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'rxjs/BehaviorSubject', '@angular/animations', '@angular/platform-browser', 'moment', '@angular/forms', '@angular/common', '@angular/platform-browser/animations'], factory) :
	(factory((global['ngx-material-timepicker'] = {}),global.ng.core,global.Rx,global.ng.animations,global.ng.platformBrowser,global.moment,global.ng.forms,global.ng.common,global.ng.platformBrowser.animations));
}(this, (function (exports,core,BehaviorSubject,animations,platformBrowser,moment,forms,common,animations$1) { 'use strict';

var TimePeriod = {
    AM: 'AM',
    PM: 'PM',
};
var DEFAULT_HOUR = {
    time: 12,
    angle: 360
};
var DEFAULT_MINUTE = {
    time: '00',
    angle: 360
};
var NgxMaterialTimepickerService = (function () {
    function NgxMaterialTimepickerService() {
        this.hourSubject = new BehaviorSubject.BehaviorSubject(DEFAULT_HOUR);
        this.minuteSubject = new BehaviorSubject.BehaviorSubject(DEFAULT_MINUTE);
        this.periodSubject = new BehaviorSubject.BehaviorSubject(TimePeriod.AM);
    }
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "hour", {
        set: function (hour) {
            this.hourSubject.next(hour);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "selectedHour", {
        get: function () {
            return this.hourSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "minute", {
        set: function (minute) {
            this.minuteSubject.next(minute);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "selectedMinute", {
        get: function () {
            return this.minuteSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "period", {
        set: function (period) {
            this.periodSubject.next(period);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "selectedPeriod", {
        get: function () {
            return this.periodSubject.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxMaterialTimepickerService.prototype, "fullTime", {
        get: function () {
            var hour = this.hourSubject.getValue().time;
            var minute = this.minuteSubject.getValue().time;
            var period = this.periodSubject.getValue();
            return hour + ":" + minute + " " + period;
        },
        enumerable: true,
        configurable: true
    });
    return NgxMaterialTimepickerService;
}());
NgxMaterialTimepickerService.decorators = [
    { type: core.Injectable },
];
NgxMaterialTimepickerService.ctorParameters = function () { return []; };
var TimeUnit = {
    HOUR: 0,
    MINUTE: 1,
};
TimeUnit[TimeUnit.HOUR] = "HOUR";
TimeUnit[TimeUnit.MINUTE] = "MINUTE";
var AnimationState = {
    ENTER: 'enter',
    LEAVE: 'leave',
};
var NgxMaterialTimepickerComponent = (function () {
    function NgxMaterialTimepickerComponent(timepickerService) {
        this.timepickerService = timepickerService;
        this.timePeriod = TimePeriod;
        this.timeUnit = TimeUnit;
        this.activeTimeUnit = TimeUnit.HOUR;
        this.isOpened = false;
        this.timeSet = new core.EventEmitter();
    }
    NgxMaterialTimepickerComponent.prototype.ngOnInit = function () {
        this.selectedHour = this.timepickerService.selectedHour;
        this.selectedMinute = this.timepickerService.selectedMinute;
        this.selectedPeriod = this.timepickerService.selectedPeriod;
    };
    NgxMaterialTimepickerComponent.prototype.onHourChange = function (hour) {
        this.timepickerService.hour = hour;
    };
    NgxMaterialTimepickerComponent.prototype.onMinuteChange = function (minute) {
        this.timepickerService.minute = minute;
    };
    NgxMaterialTimepickerComponent.prototype.changePeriod = function (period) {
        this.timepickerService.period = period;
    };
    NgxMaterialTimepickerComponent.prototype.changeTimeUnit = function (unit) {
        this.activeTimeUnit = unit;
    };
    NgxMaterialTimepickerComponent.prototype.setTime = function () {
        this.timeSet.next(this.timepickerService.fullTime);
        this.close();
    };
    NgxMaterialTimepickerComponent.prototype.open = function () {
        this.isOpened = true;
        this.animationState = AnimationState.ENTER;
    };
    NgxMaterialTimepickerComponent.prototype.close = function () {
        this.animationState = AnimationState.LEAVE;
    };
    NgxMaterialTimepickerComponent.prototype.animationDone = function (event) {
        if (event.phaseName === 'done' && event.toState === AnimationState.LEAVE) {
            this.isOpened = false;
        }
    };
    return NgxMaterialTimepickerComponent;
}());
NgxMaterialTimepickerComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-material-timepicker',
                template: "<div class=\"timepicker-overlay\" *ngIf=\"isOpened\">\n  <div class=\"timepicker\" [@timepicker]=\"animationState\" (@timepicker.done)=\"animationDone($event)\">\n    <header class=\"timepicker__header\">\n      <div class=\"timepicker-dial\">\n        <div class=\"timepicker-dial__time\">\n\t\t\t\t<span class=\"timepicker-dial__item\"\n              [ngClass]=\"{'timepicker-dial__item_active': activeTimeUnit === timeUnit.HOUR}\"\n              (click)=\"changeTimeUnit(timeUnit.HOUR)\">\n\t\t\t\t\t{{(selectedHour | async)?.time | timeFormatter: timeUnit.HOUR}}</span>:<span\n          class=\"timepicker-dial__item\"\n          [ngClass]=\"{'timepicker-dial__item_active': activeTimeUnit === timeUnit.MINUTE}\"\n          (click)=\"changeTimeUnit(timeUnit.MINUTE)\">{{(selectedMinute | async)?.time | timeFormatter: timeUnit.MINUTE}}</span>\n        </div>\n        <div class=\"timepicker-dial__period\">\n\t\t\t<span class=\"timepicker-dial__item\"\n            [ngClass]=\"{'timepicker-dial__item_active': (selectedPeriod|async) === timePeriod.AM}\"\n            (click)=\"changePeriod(timePeriod.AM)\">AM</span>\n          <span class=\"timepicker-dial__item\"\n                [ngClass]=\"{'timepicker-dial__item_active': (selectedPeriod|async) === timePeriod.PM}\"\n                (click)=\"changePeriod(timePeriod.PM)\">PM</span>\n        </div>\n      </div>\n    </header>\n    <div class=\"timepicker__body\" [ngSwitch]=\"activeTimeUnit\">\n      <ngx-material-timepicker-hours-face *ngSwitchCase=\"timeUnit.HOUR\"\n                                          (hourChange)=\"onHourChange($event)\"\n                                          [selectedHour]=\"selectedHour|async\"\n                                          (hourSelected)=\"activeTimeUnit = timeUnit.MINUTE\"></ngx-material-timepicker-hours-face>\n      <ngx-material-timepicker-minutes-face *ngSwitchCase=\"timeUnit.MINUTE\"\n                                            [selectedMinute]=\"selectedMinute|async\"\n                                            (minuteChange)=\"onMinuteChange($event)\"></ngx-material-timepicker-minutes-face>\n    </div>\n    <div class=\"timepicker__actions\">\n      <div (click)=\"close()\">\n        <ng-container *ngTemplateOutlet=\"cancelBtn ? cancelBtn : cancelBtnDefault\"></ng-container>\n      </div>\n      <div (click)=\"setTime()\">\n        <ng-container *ngTemplateOutlet=\"confirmBtn ? confirmBtn : confirmBtnDefault\"></ng-container>\n      </div>\n    </div>\n  </div>\n</div>\n<ng-template #cancelBtnDefault>\n  <ngx-material-timepicker-button>Cancel</ngx-material-timepicker-button>\n</ng-template>\n<ng-template #confirmBtnDefault>\n  <ngx-material-timepicker-button>Ok</ngx-material-timepicker-button>\n</ng-template>\n",
                styles: ["@import url(https://fonts.googleapis.com/css?family=Roboto:400,500,700);.timepicker-overlay{position:fixed;top:0;left:0;width:100%;height:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;background-color:rgba(0,0,0,.3);z-index:999}.timepicker{width:300px;border-radius:2px;-webkit-box-shadow:rgba(0,0,0,.25) 0 14px 45px,rgba(0,0,0,.22) 0 10px 18px;box-shadow:rgba(0,0,0,.25) 0 14px 45px,rgba(0,0,0,.22) 0 10px 18px}.timepicker__header{background-color:#00bfff;padding:15px 30px}.timepicker__body{background-color:#fff;padding:15px 5px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.timepicker__actions{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding:15px;background-color:#fff}.timepicker-dial{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}.timepicker-dial__time{line-height:normal;font-size:50px;color:rgba(255,255,255,.5);font-family:Roboto,sans-serif}.timepicker-dial__period{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;margin-left:10px;font-size:14px;font-weight:500;font-family:Roboto,sans-serif}.timepicker-dial__item{cursor:pointer;color:rgba(255,255,255,.5);font-family:Roboto,sans-serif}.timepicker-dial__item_active{color:#fff}"],
                animations: [
                    animations.trigger('timepicker', [
                        animations.transition("* => " + AnimationState.ENTER, [
                            animations.style({ transform: 'translateY(-30%)' }),
                            animations.animate('0.2s ease-out', animations.style({ transform: 'translateY(0)' }))
                        ]),
                        animations.transition(AnimationState.ENTER + " => " + AnimationState.LEAVE, [
                            animations.style({ transform: 'translateY(0)', opacity: 1 }),
                            animations.animate('0.2s ease-out', animations.style({ transform: 'translateY(-30%)', opacity: 0 }))
                        ])
                    ])
                ]
            },] },
];
NgxMaterialTimepickerComponent.ctorParameters = function () { return [
    { type: NgxMaterialTimepickerService, },
]; };
NgxMaterialTimepickerComponent.propDecorators = {
    "cancelBtn": [{ type: core.Input, args: ['cancelButtonTemplate',] },],
    "confirmBtn": [{ type: core.Input, args: ['cancelButtonTemplate',] },],
    "timeSet": [{ type: core.Output },],
};
var StyleSanitizerPipe = (function () {
    function StyleSanitizerPipe(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    StyleSanitizerPipe.prototype.transform = function (value) {
        if (!value) {
            return value;
        }
        return this.domSanitizer.bypassSecurityTrustStyle(value);
    };
    return StyleSanitizerPipe;
}());
StyleSanitizerPipe.decorators = [
    { type: core.Pipe, args: [{
                name: 'styleSanitizer'
            },] },
];
StyleSanitizerPipe.ctorParameters = function () { return [
    { type: platformBrowser.DomSanitizer, },
]; };
var HOURS = 12;
var NgxMaterialTimepickerHoursFaceComponent = (function () {
    function NgxMaterialTimepickerHoursFaceComponent() {
        this.hoursList = [];
        this.hourChange = new core.EventEmitter();
        this.hourSelected = new core.EventEmitter();
        for (var i = 1; i < HOURS + 1; i++) {
            var angleStep = 360 / HOURS;
            this.hoursList.push({ time: i, angle: angleStep * i });
        }
    }
    NgxMaterialTimepickerHoursFaceComponent.prototype.onMouseup = function () {
        this.hourSelected.next();
    };
    return NgxMaterialTimepickerHoursFaceComponent;
}());
NgxMaterialTimepickerHoursFaceComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-material-timepicker-hours-face',
                template: "<ngx-material-timepicker-face [selectedTime]=\"selectedHour\" [faceTime]=\"hoursList\"\n                              (timeChange)=\"hourChange.next($event)\"></ngx-material-timepicker-face>\n"
            },] },
];
NgxMaterialTimepickerHoursFaceComponent.ctorParameters = function () { return []; };
NgxMaterialTimepickerHoursFaceComponent.propDecorators = {
    "selectedHour": [{ type: core.Input },],
    "hourChange": [{ type: core.Output },],
    "hourSelected": [{ type: core.Output },],
    "onMouseup": [{ type: core.HostListener, args: ['click',] },],
};
var MINUTES = 60;
var NgxMaterialTimepickerMinutesFaceComponent = (function () {
    function NgxMaterialTimepickerMinutesFaceComponent() {
        this.minutesList = [];
        this.timeUnit = TimeUnit;
        this.minuteChange = new core.EventEmitter();
        for (var i = 0; i < MINUTES; i++) {
            var angleStep = 360 / MINUTES;
            var angle = angleStep * i;
            this.minutesList.push({ time: i === 0 ? '00' : i, angle: angle !== 0 ? angle : 360 });
        }
    }
    return NgxMaterialTimepickerMinutesFaceComponent;
}());
NgxMaterialTimepickerMinutesFaceComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-material-timepicker-minutes-face',
                template: "<ngx-material-timepicker-face [faceTime]=\"minutesList\" [selectedTime]=\"selectedMinute\"\n                              (timeChange)=\"minuteChange.next($event)\" [unit]=\"timeUnit.MINUTE\"></ngx-material-timepicker-face>\n"
            },] },
];
NgxMaterialTimepickerMinutesFaceComponent.ctorParameters = function () { return []; };
NgxMaterialTimepickerMinutesFaceComponent.propDecorators = {
    "selectedMinute": [{ type: core.Input },],
    "minuteChange": [{ type: core.Output },],
};
var NgxMaterialTimepickerFaceComponent = (function () {
    function NgxMaterialTimepickerFaceComponent() {
        this.timeUnit = TimeUnit;
        this.timeChange = new core.EventEmitter();
    }
    NgxMaterialTimepickerFaceComponent.prototype.ngAfterViewInit = function () {
        this.setClockHandPosition();
        this.setListeners();
    };
    NgxMaterialTimepickerFaceComponent.prototype.setListeners = function () {
        var mouseMoveListener = this.moveClockStick.bind(this);
        var clockFaceElement = this.clockFace.nativeElement;
        clockFaceElement.addEventListener('mousedown', function (e) {
            e.preventDefault();
            clockFaceElement.addEventListener('mousemove', mouseMoveListener);
        });
        clockFaceElement.addEventListener('mouseup', function (e) {
            e.preventDefault();
            clockFaceElement.removeEventListener('mousemove', mouseMoveListener);
        });
        clockFaceElement.addEventListener('click', mouseMoveListener);
    };
    NgxMaterialTimepickerFaceComponent.prototype.moveClockStick = function (e) {
        e.preventDefault();
        var clockFaceCords = this.clockFace.nativeElement.getBoundingClientRect();
        var centerX = clockFaceCords.x + clockFaceCords.width / 2;
        var centerY = clockFaceCords.y + clockFaceCords.height / 2;
        var arctangent = Math.atan(Math.abs(e.clientX - centerX) / Math.abs(e.clientY - centerY)) * 180 / Math.PI;
        var circleAngle = countAngleByCords(centerX, centerY, e.clientX, e.clientY, arctangent);
        var roundedAngle = roundAngle(circleAngle, 360 / this.faceTime.length);
        var selectedTime = this.faceTime.find(function (val) { return val.angle === roundedAngle; });
        this.clockHand.nativeElement.style.transform = "rotate(" + roundedAngle + "deg)";
        this.timeChange.next(selectedTime);
    };
    NgxMaterialTimepickerFaceComponent.prototype.setClockHandPosition = function () {
        this.clockHand.nativeElement.style.transform = "rotate(" + this.selectedTime.angle + "deg)";
    };
    return NgxMaterialTimepickerFaceComponent;
}());
NgxMaterialTimepickerFaceComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-material-timepicker-face',
                template: "<div class=\"clock-face\" #clockFace>\n  <div *ngIf=\"unit !== timeUnit.MINUTE;else minutesFace\" class=\"clock-face__container\">\n    <div class=\"clock-face__number\"\n         [style.transform]=\"'rotateZ('+ time.angle +'deg) translateX(-50%)' | styleSanitizer\"\n         *ngFor=\"let time of faceTime\">\n\t\t\t<span [style.transform]=\"'rotateZ(-'+ time.angle +'deg)' | styleSanitizer\"\n            [ngClass]=\"{'active': time.time === (selectedTime.time)}\">{{time.time}}</span>\n    </div>\n  </div>\n  <span class=\"clock-face__clock-hand\" [ngClass]=\"{'clock-face__clock-hand_minute': unit === timeUnit.MINUTE}\"\n        #clockHand></span>\n</div>\n<ng-template #minutesFace>\n  <div class=\"clock-face__container\">\n    <div class=\"clock-face__number\"\n         [style.transform]=\"'rotateZ('+ time.angle +'deg) translateX(-50%)' | styleSanitizer\"\n         *ngFor=\"let time of faceTime\">\n\t<span [style.transform]=\"'rotateZ(-'+ time.angle +'deg)' | styleSanitizer\"\n        [ngClass]=\"{'active': (selectedTime.time === time.time) && time.time % 5 === 0}\">\n\t{{time.time % 5 === 0 ? time.time : ''}}</span>\n    </div>\n  </div>\n</ng-template>\n",
                styles: ["@import url(https://fonts.googleapis.com/css?family=Roboto:400,500,700);.clock-face{width:290px;height:290px;border-radius:50%;background-color:#f0f0f0;position:relative;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:20px;-webkit-box-sizing:border-box;box-sizing:border-box}.clock-face__container{margin-left:-2px}.clock-face__number{position:absolute;font-size:16px;color:grey;-webkit-transform-origin:0 100%;transform-origin:0 100%;height:125px;width:50px;text-align:center;z-index:2}.clock-face__number>span{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:30px;height:30px;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;margin:auto;border-radius:50%;font-weight:500;font-family:Roboto,sans-serif}.clock-face__number>span.active{background-color:#00bfff;color:#fff}.clock-face__clock-hand{display:block;height:110px;width:2px;background-color:#00bfff;-webkit-transform-origin:0 100%;transform-origin:0 100%;position:absolute;top:calc(50% - 110px);z-index:1}.clock-face__clock-hand:after{content:'';width:7px;height:7px;border-radius:50%;background-color:#00bfff;position:absolute;bottom:-3px;left:-3.5px}.clock-face__clock-hand_minute:before{content:'';width:7px;height:7px;background-color:#fff;border:4px solid #00bfff;border-radius:50%;position:absolute;top:-3px;left:calc(50% - 8px);-webkit-box-sizing:content-box;box-sizing:content-box}"]
            },] },
];
NgxMaterialTimepickerFaceComponent.ctorParameters = function () { return []; };
NgxMaterialTimepickerFaceComponent.propDecorators = {
    "faceTime": [{ type: core.Input },],
    "selectedTime": [{ type: core.Input },],
    "unit": [{ type: core.Input },],
    "timeChange": [{ type: core.Output },],
    "clockFace": [{ type: core.ViewChild, args: ['clockFace',] },],
    "clockHand": [{ type: core.ViewChild, args: ['clockHand',] },],
};
function roundAngle(angle, step) {
    var roundedAngle = Math.round(angle / step) * step;
    return roundedAngle === 0 ? 360 : roundedAngle;
}
function countAngleByCords(x0, y0, x, y, currentAngle) {
    if (y > y0 && x >= x0) {
        return 90 - currentAngle + 90;
    }
    else if (y > y0 && x < x0) {
        return 180 + currentAngle;
    }
    else if (y < y0 && x < x0) {
        return 90 - currentAngle + 270;
    }
    else {
        return currentAngle;
    }
}
var TimeFormatterPipe = (function () {
    function TimeFormatterPipe() {
    }
    TimeFormatterPipe.prototype.transform = function (time, timeUnit) {
        if (!time) {
            return time;
        }
        switch (timeUnit) {
            case TimeUnit.HOUR:
                return moment.utc(time * 3600 * 1000).format('HH');
            case TimeUnit.MINUTE:
                return moment.utc(time * 60 * 1000).format('mm');
        }
    };
    return TimeFormatterPipe;
}());
TimeFormatterPipe.decorators = [
    { type: core.Pipe, args: [{
                name: 'timeFormatter'
            },] },
];
TimeFormatterPipe.ctorParameters = function () { return []; };
var NgxMaterialTimepickerButtonComponent = (function () {
    function NgxMaterialTimepickerButtonComponent() {
    }
    return NgxMaterialTimepickerButtonComponent;
}());
NgxMaterialTimepickerButtonComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'ngx-material-timepicker-button',
                template: "<button class=\"timepicker-button\">\n  <span><ng-content></ng-content></span>\n</button>\n",
                styles: ["@import url(https://fonts.googleapis.com/css?family=Roboto:400,500,700);.timepicker-button{display:inline-block;height:36px;min-width:88px;line-height:36px;border:12px;border-radius:2px;background-color:transparent;color:#00bfff;text-align:center;-webkit-transition:all 450ms cubic-bezier(.23,1,.32,1);transition:all 450ms cubic-bezier(.23,1,.32,1);overflow:hidden;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;position:relative;cursor:pointer}.timepicker-button:focus,.timepicker-button:hover{background-color:rgba(153,153,153,.2)}.timepicker-button>span{font-size:14px;text-transform:uppercase;font-weight:600;padding-left:16px;padding-right:16px;font-family:Roboto,sans-serif}"]
            },] },
];
NgxMaterialTimepickerButtonComponent.ctorParameters = function () { return []; };
var TimeFormat = {
    TWELVE: 'hh:mm a',
    TWENTY_FOUR: 'HH:mm',
};
var moment$1 = moment;
var VALUE_ACCESSOR = {
    provide: forms.NG_VALUE_ACCESSOR,
    useExisting: core.forwardRef(function () { return TimepickerDirective; }),
    multi: true
};
var TWENTY_FOUR_HOUR_FORMAT = 24;
var TimepickerDirective = (function () {
    function TimepickerDirective(elementRef) {
        this.elementRef = elementRef;
        this.onTouched = function () {
        };
        this.onChange = function () {
        };
    }
    Object.defineProperty(TimepickerDirective.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (value) {
            this._value = formatTime(value, this._format);
            this.elementRef.nativeElement.value = value ? formatTime(value, this._format) : '';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TimepickerDirective.prototype, "format", {
        set: function (value) {
            this._format = value === TWENTY_FOUR_HOUR_FORMAT ? TimeFormat.TWENTY_FOUR : TimeFormat.TWELVE;
        },
        enumerable: true,
        configurable: true
    });
    TimepickerDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.timepicker) {
            this.timepickerSubscription = this.timepicker.timeSet.subscribe(function (time) {
                _this.value = time;
                _this.onChange(time);
                _this.onTouched();
            });
        }
    };
    TimepickerDirective.prototype.onInput = function (value) {
        this._value = value;
        this.onChange(value);
    };
    TimepickerDirective.prototype.onClick = function () {
        this.timepicker.open();
    };
    TimepickerDirective.prototype.writeValue = function (value) {
        this.value = value;
    };
    TimepickerDirective.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    TimepickerDirective.prototype.registerOnTouched = function (fn) {
        this.onTouched = fn;
    };
    TimepickerDirective.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    TimepickerDirective.prototype.ngOnDestroy = function () {
        this.timepickerSubscription.unsubscribe();
    };
    return TimepickerDirective;
}());
TimepickerDirective.decorators = [
    { type: core.Directive, args: [{
                selector: '[ngxTimepicker]',
                providers: [VALUE_ACCESSOR],
                host: {
                    '[disabled]': 'disabled',
                    '(input)': 'onInput($event.target.value)',
                    '(blur)': 'onTouched()',
                }
            },] },
];
TimepickerDirective.ctorParameters = function () { return [
    { type: core.ElementRef, },
]; };
TimepickerDirective.propDecorators = {
    "timepicker": [{ type: core.Input, args: ['ngxTimepicker',] },],
    "value": [{ type: core.Input },],
    "format": [{ type: core.Input },],
    "disabled": [{ type: core.Input },],
    "onClick": [{ type: core.HostListener, args: ['click',] },],
};
function formatTime(time, format) {
    if (format === void 0) { format = TimeFormat.TWELVE; }
    return moment$1(time, 'hh:mm a').format((format));
}
var NgxMaterialTimepickerModule = (function () {
    function NgxMaterialTimepickerModule() {
    }
    NgxMaterialTimepickerModule.forRoot = function () {
        return {
            ngModule: NgxMaterialTimepickerModule,
            providers: [NgxMaterialTimepickerService]
        };
    };
    return NgxMaterialTimepickerModule;
}());
NgxMaterialTimepickerModule.decorators = [
    { type: core.NgModule, args: [{
                imports: [
                    common.CommonModule,
                    animations$1.BrowserAnimationsModule
                ],
                exports: [
                    NgxMaterialTimepickerComponent,
                    TimepickerDirective
                ],
                declarations: [
                    NgxMaterialTimepickerComponent,
                    StyleSanitizerPipe,
                    NgxMaterialTimepickerHoursFaceComponent,
                    NgxMaterialTimepickerMinutesFaceComponent,
                    NgxMaterialTimepickerFaceComponent,
                    TimeFormatterPipe,
                    NgxMaterialTimepickerButtonComponent,
                    TimepickerDirective,
                ]
            },] },
];
NgxMaterialTimepickerModule.ctorParameters = function () { return []; };

exports.NgxMaterialTimepickerModule = NgxMaterialTimepickerModule;
exports.ɵj = NgxMaterialTimepickerButtonComponent;
exports.ɵh = NgxMaterialTimepickerFaceComponent;
exports.ɵf = NgxMaterialTimepickerHoursFaceComponent;
exports.ɵg = NgxMaterialTimepickerMinutesFaceComponent;
exports.ɵd = TimepickerDirective;
exports.ɵa = AnimationState;
exports.ɵb = NgxMaterialTimepickerComponent;
exports.ɵe = StyleSanitizerPipe;
exports.ɵi = TimeFormatterPipe;
exports.ɵc = NgxMaterialTimepickerService;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-material-timepicker.umd.js.map
